"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var facebook_1 = require("./broadcast/facebook");
var recime_bot_extension_1 = require("recime-bot-extension");
var MessageConverter = /** @class */ (function () {
    function MessageConverter(platform) {
        this.__ = recime_bot_extension_1.default[platform];
    }
    MessageConverter.prototype.normalizeButton = function (__, content) {
        if (content.buttons) {
            return content.buttons.map(function (button) {
                switch (button.type) {
                    case 'reply': {
                        return __.postbackButton(button.title || button.reply, "reply-" + button.reply);
                    }
                    case 'phone_number': {
                        button.payload = button.payload.replace(/[\s()-]+/ig, '');
                        return button;
                    }
                    default: {
                        return button;
                    }
                }
            });
        }
        return void 0;
    };
    MessageConverter.prototype.eval = function (message) {
        var _this = this;
        var __ = this.__;
        switch (message.type) {
            case 'text': {
                if (message.content && message.content.text.trim()) {
                    return __.text(message.content.text, this.normalizeButton(__, message.content));
                }
            }
            case 'image':
            case 'audio':
            case 'video':
            case 'file': {
                return __[message.type](message.content.url, this.normalizeButton(__, message.content));
            }
            case 'button-template': {
                return __.buttonTemplate(message.content.text, this.normalizeButton(__, message.content));
            }
            case 'card-template':
            case 'generic-template': {
                return __.genericTemplate(message.content.elements.map(function (e) {
                    return __.genericItem(e.title, e.subtitle, e.imageUrl, e.actionUrl, _this.normalizeButton(__, e));
                }));
            }
        }
    };
    return MessageConverter;
}());
var Broadcast = /** @class */ (function () {
    function Broadcast(bot) {
        this.bot = bot;
    }
    Broadcast.prototype.send = function (body) {
        switch (body.platform) {
            case 'facebook': {
                var facebook_2 = new facebook_1.Facebook(this.bot);
                var response = body.messages
                    .map(function (message) { return function () {
                    return facebook_2
                        .create(new MessageConverter(body.platform).eval(message))
                        .then(function (msgId) {
                        return facebook_2.createFilter(body.filter).then(function (label) {
                            return facebook_2.send(msgId, label);
                        });
                    })
                        .then(function (id) {
                        return { broadcast_id: id };
                    });
                }; });
                return response
                    .reduce(function (a, b) {
                    return a.then(function (messages) {
                        return b().then(function (message) {
                            messages.push(message.broadcast_id);
                            return messages;
                        });
                    });
                }, Promise.resolve([]));
            }
        }
        return Promise.resolve([]);
    };
    return Broadcast;
}());
exports.Broadcast = Broadcast;
